Name:           libpri
Version:        1.6.0
%global so_version 1.4
Release:        %autorelease
Summary:        An implementation of Primary Rate ISDN

# From README:
#   As a special exception, libpri may also be linked to the OpenH323 library,
#   so long as the entirity of the derivative work (as defined within the GPL)
#   is licensed either under the MPL of the OpenH323 license or the GPL of
#   libpri.
# From source file headers:
#   In addition, when this program is distributed with Asterisk in any form
#   that would qualify as a 'combined work' or as a 'derivative work' (but not
#   mere aggregation), you can redistribute and/or modify the combination under
#   the terms of the license provided with that copy of Asterisk, instead of
#   the license terms granted here.
# The Makefile (only) is GPLv2+, but this does not affect the license of the
# binary RPMs.
License:        GPLv2 with exceptions
URL:            https://www.asterisk.org/
%global src_base https://downloads.asterisk.org/pub/telephony/libpri/releases
Source0:        %{src_base}/libpri-%{version}.tar.gz
Source1:        %{src_base}/libpri-%{version}.tar.gz.asc
# Keyring with developer signatures created on 2021-02-23 with:
#   workdir="$(mktemp --directory)"
#   gpg2 --with-fingerprint libpri-1.6.0.tar.gz.asc 2>&1 |
#     awk '$2 == "using" { print "0x" $NF }' |
#     xargs gpg2 --homedir="${workdir}" \
#         --keyserver=hkp://pool.sks-keyservers.net --recv-keys
#   gpg2 --homedir="${workdir}" --export --export-options export-minimal \
#       > libpri.gpg
#   rm -rf "${workdir}"
# Inspect keys using:
#   gpg2 --list-keys --no-default-keyring --keyring ./libpri.gpg
Source2:        libpri.gpg

# Upstream bug PRI-186:
#   https://issues.asterisk.org/jira/browse/PRI-186
# Debian downstream bug:
#   https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=957470
# Patch from Debian, which we use unmodified:
#   https://bugs.debian.org/cgi-bin/bugreport.cgi?att=1;bug=957470;filename=zero-sized-members.patch;msg=32
Patch:          zero-sized-members.patch

BuildRequires:  gnupg2

BuildRequires:  make
BuildRequires:  gcc

BuildRequires:  dahdi-tools-devel

%description
libpri is a C implementation of the Primary Rate ISDN specification. It was
based on the Bellcore specification SR-NWT-002343 for National ISDN. As of May
12, 2001, it has been tested work to with NI-2, Nortel DMS-100, and Lucent 5E
Custom protocols on switches from Nortel and Lucent.


%package devel
Summary:        Development files for libpri
Requires:       libpri%{?_isa} = %{version}-%{release}

%description devel
The libpri-devel package contains libraries and header files for developing
applications that use libpri.


%package doc
Summary:        Documentation for libpri

BuildArch:      noarch

%description doc
Currently, the libpri-doc package contains the pseudocode for the finite state
machines used in its implementation.


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup


%build
%set_build_flags
%make_build


%install
%make_install INSTALL_BASE=%{_prefix} libdir=%{_libdir}
# Remove the static library
find %{buildroot} -name '*.a' -print -delete


%check
./rosetest
./testprilib


%files
%license LICENSE
%doc ChangeLog
%doc README
%{_libdir}/libpri.so.%{so_version}


%files devel
%{_includedir}/libpri.h
%{_libdir}/libpri.so


%files doc
%license LICENSE
%doc ChangeLog
%doc README
%doc doc/*.fsm


%changelog
%autochangelog
